@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2021-2024 Nitrokey Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import logging
 import platform
@@ -15,11 +9,11 @@ from enum import Enum, auto, unique
 from types import TracebackType
 from typing import Callable, Iterable, Optional, Sequence, Tuple, Type, Union
 
+from nitrokey.trussed import TrussedBase, Version
+
 from pynitrokey.cli.exceptions import CliException
 from pynitrokey.fido2 import device_path_to_str
 from pynitrokey.helpers import local_print
-from pynitrokey.trussed.base import NitrokeyTrussedBase
-from pynitrokey.trussed.utils import Version
 
 logger = logging.getLogger(__name__)
 
@@ -54,7 +48,7 @@ class TestResult:
         self.exc_info = exc_info
 
 
-TestCaseFn = Callable[[TestContext, NitrokeyTrussedBase], TestResult]
+TestCaseFn = Callable[[TestContext, TrussedBase], TestResult]
 
 
 class TestCase:
@@ -128,7 +122,7 @@ def list_tests(
 
 def run_tests(
     ctx: TestContext,
-    device: NitrokeyTrussedBase,
+    device: TrussedBase,
     selector: TestSelector,
     test_cases: Sequence[TestCase],
 ) -> bool:
